API docs for “spamfighter.api.message.test.test_firewall.FirewallCommandTestCase”

# Class s.a.m.t.t.FirewallCommandTestCase(unittest.TestCase):

Part of spamfighter.api.message.test.test_firewall View Source View In Hierarchy

Тест на `spamfighter.api.message.firewall.FirewallCommand`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testNoSuchFirewall | Undocumented
Method | testNotAFirewall | Undocumented
Method | testGetFirewall | Undocumented

def setUp(self): (source)
Undocumented
def tearDown(self): (source)
Undocumented
def testNoSuchFirewall(self): (source)
Undocumented
def testNotAFirewall(self): (source)
Undocumented
def testGetFirewall(self): (source)
Undocumented